@@ -4,5 +4,5 @@ from AnnotatedTree.Layer.SingleWordLayer import SingleWordLayer
 class DependencyLayer(SingleWordLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "dependency"
+        self.layer_name = "dependency"
         self.setLayerValue(layerValue)
