@@ -6,13 +6,13 @@ from AnnotatedTree.Layer.SingleWordMultiItemLayer import SingleWordMultiItemLaye
 class EnglishPropbankLayer(SingleWordMultiItemLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "englishPropbank"
+        self.layer_name = "englishPropbank"
         self.setLayerValue(layerValue)
 
     def setLayerValue(self, layerValue: str):
         self.items = []
-        self.layerValue = layerValue
+        self.layer_value = layerValue
         if layerValue is not None:
-            splitWords = layerValue.split("#")
-            for word in splitWords:
+            split_words = layerValue.split("#")
+            for word in split_words:
                 self.items.append(Argument(word))
