@@ -4,5 +4,5 @@ from AnnotatedTree.Layer.SingleWordLayer import SingleWordLayer
 class EnglishSemanticLayer(SingleWordLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "englishSemantics"
+        self.layer_name = "englishSemantics"
         self.setLayerValue(layerValue)
