@@ -5,4 +5,4 @@ class EnglishWordLayer(SourceLanguageWordLayer):
 
     def __init__(self, layerValue: str):
         super().__init__(layerValue)
-        self.layerName = "english"
+        self.layer_name = "english"
