@@ -7,15 +7,15 @@ from AnnotatedTree.Layer.MultiWordMultiItemLayer import MultiWordMultiItemLayer
 class MetaMorphemesMovedLayer(MultiWordMultiItemLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "metaMorphemesMoved"
+        self.layer_name = "metaMorphemesMoved"
         self.setLayerValue(layerValue)
 
     def setLayerValue(self, layerValue: str):
         self.items = []
-        self.layerValue = layerValue
+        self.layer_value = layerValue
         if layerValue is not None:
-            splitWords = layerValue.split(" ")
-            for word in splitWords:
+            split_words = layerValue.split(" ")
+            for word in split_words:
                 self.items.append(MetamorphicParse(word))
 
     def getLayerSize(self, viewLayer: ViewLayerType) -> int:
