@@ -10,5 +10,7 @@ class MultiWordMultiItemLayer(MultiWordLayer):
     def getLayerSize(self, viewLayer: ViewLayerType) -> int:
         pass
 
-    def getLayerInfoAt(self, viewLayer: ViewLayerType, index: int) -> str:
+    def getLayerInfoAt(self,
+                       viewLayer: ViewLayerType,
+                       index: int) -> str:
         pass
