@@ -4,5 +4,5 @@ from AnnotatedTree.Layer.TargetLanguageWordLayer import TargetLanguageWordLayer
 class PersianWordLayer(TargetLanguageWordLayer):
 
     def __init__(self, layerValue: str):
-        super().TargetLanguageWordLayer(layerValue)
-        self.layerName = "persian"
+        super().__init__(layerValue)
+        self.layer_name = "persian"
