@@ -4,12 +4,12 @@ from AnnotatedTree.Layer.MultiWordLayer import MultiWordLayer
 class ShallowParseLayer(MultiWordLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "shallowParse"
+        self.layer_name = "shallowParse"
         self.setLayerValue(layerValue)
 
     def setLayerValue(self, layerValue: str):
         self.items = []
-        self.layerValue = layerValue
+        self.layer_value = layerValue
         if layerValue is not None:
-            splitParse = layerValue.split(" ")
-            self.items.extend(splitParse)
+            split_parse = layerValue.split(" ")
+            self.items.extend(split_parse)
