@@ -4,4 +4,4 @@ from AnnotatedTree.Layer.WordLayer import WordLayer
 class SingleWordLayer(WordLayer):
 
     def setLayerValue(self, layerValue: str):
-        self.layerValue = layerValue
+        self.layer_value = layerValue
