@@ -4,12 +4,12 @@ from AnnotatedTree.Layer.MultiWordLayer import MultiWordLayer
 class TurkishSemanticLayer(MultiWordLayer):
 
     def __init__(self, layerValue: str):
-        self.layerName = "semantics"
+        self.layer_name = "semantics"
         self.setLayerValue(layerValue)
 
     def setLayerValue(self, layerValue: str):
         self.items = []
-        self.layerValue = layerValue
+        self.layer_value = layerValue
         if layerValue is not None:
-            splitMeanings = layerValue.split("\\$")
-            self.items.extend(splitMeanings)
+            split_meanings = layerValue.split("\\$")
+            self.items.extend(split_meanings)
