@@ -5,4 +5,4 @@ class TurkishWordLayer(TargetLanguageWordLayer):
 
     def __init__(self, layerValue: str):
         super().__init__(layerValue)
-        self.layerName = "turkish"
+        self.layer_name = "turkish"
