@@ -6,13 +6,13 @@ from AnnotatedTree.Processor.Condition.IsLeafNode import IsLeafNode
 
 class IsNoneNode(IsLeafNode):
 
-    __secondLanguage: ViewLayerType
+    __second_language: ViewLayerType
 
     def __init__(self, secondLanguage: ViewLayerType):
-        self.__secondLanguage = secondLanguage
+        self.__second_language = secondLanguage
 
     def satisfies(self, parseNode: ParseNodeDrawable) -> bool:
         if super().satisfies(parseNode):
-            data = parseNode.getLayerData(self.__secondLanguage)
+            data = parseNode.getLayerData(self.__second_language)
             return data is not None and data == "*NONE*"
         return False
