@@ -9,6 +9,6 @@ class IsNullElement(IsLeafNode):
     def satisfies(self, parseNode: ParseNodeDrawable) -> bool:
         if super().satisfies(parseNode):
             data = parseNode.getLayerData(ViewLayerType.ENGLISH_WORD)
-            parentData = parseNode.getParent().getData().getName()
-            return "*" in data or (data == "0" and parentData == "-NONE-")
+            parent_data = parseNode.getParent().getData().getName()
+            return "*" in data or (data == "0" and parent_data == "-NONE-")
         return False
