@@ -11,6 +11,6 @@ class IsNumber(IsLeafNode):
     def satisfies(self, parseNode: ParseNodeDrawable) -> bool:
         if super().satisfies(parseNode):
             data = parseNode.getLayerData(ViewLayerType.ENGLISH_WORD)
-            parentData = parseNode.getParent().getData().getName()
-            return parentData == "CD" and re.fullmatch("[0-9,.]+", data) is not None
+            parent_data = parseNode.getParent().getData().getName()
+            return parent_data == "CD" and re.fullmatch("[0-9,.]+", data) is not None
         return False
