@@ -6,4 +6,4 @@ from AnnotatedTree.Processor.LeafConverter.LeafToLanguageConverter import LeafTo
 class LeafToEnglish(LeafToLanguageConverter):
 
     def __init__(self):
-        self.viewLayerType = ViewLayerType.ENGLISH_WORD
+        self.view_layer_type = ViewLayerType.ENGLISH_WORD
