@@ -5,10 +5,10 @@ from AnnotatedTree.Processor.LeafConverter.LeafToStringConverter import LeafToSt
 class LeafToRootFormConverter(LeafToStringConverter):
 
     def leafConverter(self, parseNodeDrawable: ParseNodeDrawable) -> str:
-        layerInfo = parseNodeDrawable.getLayerInfo()
-        rootWords = " "
-        for i in range(layerInfo.getNumberOfWords()):
-            root = layerInfo.getMorphologicalParseAt(i).getWord().getName()
+        layer_info = parseNodeDrawable.getLayerInfo()
+        root_words = " "
+        for i in range(layer_info.getNumberOfWords()):
+            root = layer_info.getMorphologicalParseAt(i).getWord().getName()
             if root is not None and len(root) != 0:
-                rootWords += " " + root
-        return rootWords
+                root_words += " " + root
+        return root_words
