@@ -5,17 +5,17 @@ from AnnotatedTree.Processor.NodeModification.NodeModifier import NodeModifier
 
 class TreeModifier:
 
-    __parseTree: ParseTreeDrawable
-    __nodeModifier: NodeModifier
+    __parse_tree: ParseTreeDrawable
+    __node_modifier: NodeModifier
 
     def nodeModify(self, parseNode: ParseNodeDrawable):
-        self.__nodeModifier.modifier(parseNode)
+        self.__node_modifier.modifier(parseNode)
         for i in range(parseNode.numberOfChildren()):
             self.nodeModify(parseNode.getChild(i))
 
     def modify(self):
-        self.nodeModify(self.__parseTree.getRoot())
+        self.nodeModify(self.__parse_tree.getRoot())
 
     def __init__(self, parseTree: ParseTreeDrawable, nodeModifier: NodeModifier):
-        self.__parseTree = parseTree
-        self.__nodeModifier = nodeModifier
+        self.__parse_tree = parseTree
+        self.__node_modifier = nodeModifier
